Trait JsonSchema

pub trait JsonSchema {
    // Required methods
    fn schema_name() -> String;
    fn json_schema(generator: &mut SchemaGenerator) -> Schema;

    // Provided methods
    fn is_referenceable() -> bool { ... }
    fn schema_id() -> Cow<'static, str> { ... }
}
A type which can be described as a JSON Schema document.

This is implemented for many Rust primitive and standard library types.

This can also be automatically derived on most custom types with #[derive(JsonSchema)].

Examples

Deriving an implementation:

use schemars::{schema_for, JsonSchema};

#[derive(JsonSchema)]
struct MyStruct {
    foo: i32,
}

let my_schema = schema_for!(MyStruct);

When manually implementing JsonSchema, as well as determining an appropriate schema, you will need to determine an appropriate name and ID for the type. For non-generic types, the type name/path are suitable for this:

use schemars::{r#gen::SchemaGenerator, schema::Schema, JsonSchema};
use std::borrow::Cow;

struct NonGenericType;

impl JsonSchema for NonGenericType {
    fn schema_name() -> String {
        // Exclude the module path to make the name in generated schemas clearer.
        "NonGenericType".to_owned()
    }

    fn schema_id() -> Cow<'static, str> {
        // Include the module, in case a type with the same name is in another module/crate
        Cow::Borrowed(concat!(module_path!(), "::NonGenericType"))
    }

    fn json_schema(_generator: &mut SchemaGenerator) -> Schema {
        todo!()
    }
}

assert_eq!(NonGenericType::schema_id(), <&mut NonGenericType>::schema_id());

But generic type parameters which may affect the generated schema should typically be included in the name/ID:

use schemars::{r#gen::SchemaGenerator, schema::Schema, JsonSchema};
use std::{borrow::Cow, marker::PhantomData};

struct GenericType<T>(PhantomData<T>);

impl<T: JsonSchema> JsonSchema for GenericType<T> {
    fn schema_name() -> String {
        format!("GenericType_{}", T::schema_name())
    }

    fn schema_id() -> Cow<'static, str> {
        Cow::Owned(format!(
            "{}::GenericType<{}>",
            module_path!(),
            T::schema_id()
        ))
    }

    fn json_schema(_generator: &mut SchemaGenerator) -> Schema {
        todo!()
    }
}

assert_eq!(<GenericType<i32>>::schema_id(), <&mut GenericType<&i32>>::schema_id());

Required Methods

fn schema_name() -> String

The name of the generated JSON Schema.

This is used as the title for root schemas, and the key within the root’s definitions property for subschemas.

fn json_schema(generator: &mut SchemaGenerator) -> Schema

Generates a JSON Schema for this type.

If the returned schema depends on any referenceable schemas, then this method will add them to the SchemaGenerator’s schema definitions.

This should not return a $ref schema.

Provided Methods

fn is_referenceable() -> bool

Whether JSON Schemas generated for this type should be re-used where possible using the $ref keyword.

For trivial types (such as primitives), this should return false. For more complex types, it should return true. For recursive types, this must return true to prevent infinite cycles when generating schemas.

By default, this returns true.

fn schema_id() -> Cow<'static, str>

Returns a string that uniquely identifies the schema produced by this type.

This does not have to be a human-readable string, and the value will not itself be included in generated schemas. If two types produce different schemas, then they must have different schema_id()s, but two types that produce identical schemas should ideally have the same schema_id().

The default implementation returns the same value as schema_name().

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types



impl JsonSchema for IpAddr



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for SocketAddr



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for Weekday



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for Value



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for bool



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for char



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for f32



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for f64



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for i8



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for i16



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for i32



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for i64



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for i128



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for isize



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for str



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for u8



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for u16



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for u32



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for u64



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for u128



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for ()



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for usize



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for CString



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for String



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for CStr



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for Ipv4Addr



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for Ipv6Addr



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for SocketAddrV4



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for SocketAddrV6



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for NonZero<i8>



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for NonZero<i16>



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for NonZero<i32>



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for NonZero<i64>



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for NonZero<i128>



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for NonZero<isize>



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for NonZero<u8>



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for NonZero<u16>



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for NonZero<u32>



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for NonZero<u64>



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for NonZero<u128>



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for NonZero<usize>



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for AtomicBool



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for AtomicI8



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for AtomicI16



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for AtomicI32



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for AtomicI64



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for AtomicIsize



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for AtomicU8



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for AtomicU16



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for AtomicU32



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for AtomicU64



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for AtomicUsize



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for Duration



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for OsStr



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for OsString



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for Path



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for PathBuf



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for SystemTime



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for NaiveDate



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for NaiveDateTime



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for NaiveTime



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for Map<String, Value>



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl JsonSchema for Number



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl JsonSchema for I18nString



fn schema_name() -> String



fn json_schema(_generator: &mut SchemaGenerator) -> Schema



impl<'a> JsonSchema for Arguments<'a>



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<'a, T> JsonSchema for Cow<'a, T>
where T: ToOwned + JsonSchema + ?Sized,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<'a, T> JsonSchema for &'a T
where T: JsonSchema + ?Sized,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<'a, T> JsonSchema for &'a mut T
where T: JsonSchema + ?Sized,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<K, V> JsonSchema for BTreeMap<K, V>
where V: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<K, V, H> JsonSchema for HashMap<K, V, H>
where V: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T0> JsonSchema for (T0,)
where T0: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T0, T1> JsonSchema for (T0, T1)
where T0: JsonSchema, T1: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T0, T1, T2> JsonSchema for (T0, T1, T2)
where T0: JsonSchema, T1: JsonSchema, T2: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T0, T1, T2, T3> JsonSchema for (T0, T1, T2, T3)
where T0: JsonSchema, T1: JsonSchema, T2: JsonSchema, T3: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T0, T1, T2, T3, T4> JsonSchema for (T0, T1, T2, T3, T4)
where T0: JsonSchema, T1: JsonSchema, T2: JsonSchema, T3: JsonSchema, T4: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T0, T1, T2, T3, T4, T5> JsonSchema for (T0, T1, T2, T3, T4, T5)
where T0: JsonSchema, T1: JsonSchema, T2: JsonSchema, T3: JsonSchema, T4: JsonSchema, T5: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T0, T1, T2, T3, T4, T5, T6> JsonSchema for (T0, T1, T2, T3, T4, T5, T6)
where T0: JsonSchema, T1: JsonSchema, T2: JsonSchema, T3: JsonSchema, T4: JsonSchema, T5: JsonSchema, T6: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T0, T1, T2, T3, T4, T5, T6, T7> JsonSchema for (T0, T1, T2, T3, T4, T5, T6, T7)



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T0, T1, T2, T3, T4, T5, T6, T7, T8> JsonSchema for (T0, T1, T2, T3, T4, T5, T6, T7, T8)



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> JsonSchema for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> JsonSchema for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> JsonSchema for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12> JsonSchema for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12)



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13> JsonSchema for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13)



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14> JsonSchema for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14)
where T0: JsonSchema, T1: JsonSchema, T2: JsonSchema, T3: JsonSchema, T4: JsonSchema, T5: JsonSchema, T6: JsonSchema, T7: JsonSchema, T8: JsonSchema, T9: JsonSchema, T10: JsonSchema, T11: JsonSchema, T12: JsonSchema, T13: JsonSchema, T14: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> JsonSchema for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15)
where T0: JsonSchema, T1: JsonSchema, T2: JsonSchema, T3: JsonSchema, T4: JsonSchema, T5: JsonSchema, T6: JsonSchema, T7: JsonSchema, T8: JsonSchema, T9: JsonSchema, T10: JsonSchema, T11: JsonSchema, T12: JsonSchema, T13: JsonSchema, T14: JsonSchema, T15: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for Bound<T>
where T: JsonSchema,



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for Option<T>
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 0]



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 1]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 2]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 3]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 4]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 5]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 6]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 7]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 8]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 9]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 10]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 11]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 12]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 13]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 14]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 15]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 16]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 17]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 18]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 19]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 20]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 21]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 22]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 23]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 24]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 25]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 26]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 27]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 28]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 29]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 30]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 31]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T; 32]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for [T]
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for Box<T>
where T: JsonSchema + ?Sized,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for BinaryHeap<T>
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for BTreeSet<T>
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for LinkedList<T>
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for VecDeque<T>
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for Rc<T>
where T: JsonSchema + ?Sized,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for Weak<T>
where T: JsonSchema + ?Sized,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for Arc<T>
where T: JsonSchema + ?Sized,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for Weak<T>
where T: JsonSchema + ?Sized,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for Vec<T>
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for Cell<T>
where T: JsonSchema + ?Sized,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for RefCell<T>
where T: JsonSchema + ?Sized,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for Reverse<T>
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for PhantomData<T>
where T: ?Sized,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for Wrapping<T>
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for Range<T>
where T: JsonSchema,



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for RangeInclusive<T>
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for Mutex<T>
where T: JsonSchema + ?Sized,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T> JsonSchema for RwLock<T>
where T: JsonSchema + ?Sized,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T, E> JsonSchema for Result<T, E>
where T: JsonSchema, E: JsonSchema,



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<T, H> JsonSchema for HashSet<T, H>
where T: JsonSchema,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(generator: &mut SchemaGenerator) -> Schema



impl<Tz> JsonSchema for DateTime<Tz>
where Tz: TimeZone,



fn is_referenceable() -> bool



fn schema_name() -> String



fn schema_id() -> Cow<'static, str>



fn json_schema(_: &mut SchemaGenerator) -> Schema

Implementors

Source

impl JsonSchema for AbilityCaseRollType

Source

impl JsonSchema for AbilityCastType

Source

impl JsonSchema for AbilityFightUiVisibility

Source

impl JsonSchema for AdPlacement

Source

impl JsonSchema for ArenaLeaderboardResponse

Source

impl JsonSchema for ArenaMatchesHistoryResponse

Source

impl JsonSchema for ArenaPvpPlayersResponse

Source

impl JsonSchema for BundleClaimMode

Source

impl JsonSchema for BundleElement

Source

impl JsonSchema for BundleStepGeneric

Source

impl JsonSchema for BundleStepType

Source

impl JsonSchema for GetCharacterStateResponse

Source

impl JsonSchema for FightClass

Source

impl JsonSchema for ChatType

Source

impl JsonSchema for ClassAttribute

Source

impl JsonSchema for ClassTier

Source

impl JsonSchema for CurrencyConsumer

Source

impl JsonSchema for CurrencySource

Source

impl JsonSchema for RewardType

Source

impl JsonSchema for EntityTeam

Source

impl JsonSchema for EntityType

Source

impl JsonSchema for FightType

Source

impl JsonSchema for GiftType

Source

impl JsonSchema for ItemType

Source

impl JsonSchema for MailRepeatType

Source

impl JsonSchema for PaymentType

Source

impl JsonSchema for ShopTab

Source

impl JsonSchema for OpponentState

Source

impl JsonSchema for PetCaseRollType

Source

impl JsonSchema for PetSlotType

Source

impl JsonSchema for StarsChange

Source

impl JsonSchema for VassalPvpPlayersFindResponse

Source

impl JsonSchema for QuestGroupType

Source

impl JsonSchema for RatingLeaderboardResponse

Source

impl JsonSchema for RatingType

Source

impl JsonSchema for GetReferralsResponse

Source

impl JsonSchema for ScreenType

Source

impl JsonSchema for SkinType

Source

impl JsonSchema for TalentBackendModifier

Source

impl JsonSchema for CharacterResetType

Source

impl JsonSchema for VassalTaskStatus

Source

impl JsonSchema for Ability

Source

impl JsonSchema for AbilityDrop

Source

impl JsonSchema for AbilityRarity

Source

impl JsonSchema for AbilityTemplate

Source

impl JsonSchema for ActiveAbility

Source

impl JsonSchema for EquippedAbilities

Source

impl JsonSchema for UpgradedAbilitiesMap

Source

impl JsonSchema for AbilityPresetsSettings

Source

impl JsonSchema for AdUsageData

Source

impl JsonSchema for Arena

Source

impl JsonSchema for ArenaLeaderboardRequest

Source

impl JsonSchema for ArenaMatchesHistoryRequest

Source

impl JsonSchema for ArenaPvpPlayersRequest

Source

impl JsonSchema for ArenaStars

Source

impl JsonSchema for ArenaTickets

Source

impl JsonSchema for League

Source

impl JsonSchema for Match

Source

impl JsonSchema for RankingItem

Source

impl JsonSchema for AutoChest

Source

impl JsonSchema for AutoChestFilter

Source

impl JsonSchema for Bot

Source

impl JsonSchema for ActiveBuff

Source

impl JsonSchema for BundleAbility

Source

impl JsonSchema for BundleRaw

Source

impl JsonSchema for BundleRawStep

Source

impl JsonSchema for BundleStep

Source

impl JsonSchema for CharacterSettings

Source

impl JsonSchema for CharacterState

Source

impl JsonSchema for FullClearCharacterRequest

Source

impl JsonSchema for GetCharacterStateRequest

Source

impl JsonSchema for Character

Source

impl JsonSchema for Chat

Source

impl JsonSchema for ChatMessage

Source

impl JsonSchema for ChatSettings

Source

impl JsonSchema for ReadMessage

Source

impl JsonSchema for ReportChatMessage

Source

impl JsonSchema for Class

Source

impl JsonSchema for ClassTransition

Source

impl JsonSchema for Currency

Source

impl JsonSchema for CurrencyUnit

Source

impl JsonSchema for DungeonRewards

Source

impl JsonSchema for DungeonTemplate

Source

impl JsonSchema for DungeonTip

Source

impl JsonSchema for Dungeons

Source

impl JsonSchema for GuaranteedReward

Source

impl JsonSchema for Effect

Source

impl JsonSchema for Coordinates

Source

impl JsonSchema for Entity

Source

impl JsonSchema for EntityAttributes

Source

impl JsonSchema for ActiveDungeon

Source

impl JsonSchema for ActiveFight

Source

impl JsonSchema for ActivePetAbility

Source

impl JsonSchema for FightEntity

Source

impl JsonSchema for FightTemplate

Source

impl JsonSchema for AbilitySlotsLevel

Source

impl JsonSchema for Chapter

Source

impl JsonSchema for CharacterLevel

Source

impl JsonSchema for EnemyReward

Source

impl JsonSchema for EntityAttribute

Source

impl JsonSchema for EntityTemplate

Source

impl JsonSchema for PetSlotsLevel

Source

impl JsonSchema for AutoChestGatings

Source

impl JsonSchema for CastleGating

Source

impl JsonSchema for Gatings

Source

impl JsonSchema for NavBarNavigation

Source

impl JsonSchema for SideBarNavigation

Source

impl JsonSchema for BotsSettings

Source

impl JsonSchema for PhotoGenerationSettings

Source

impl JsonSchema for UsernameGenerationSettings

Source

impl JsonSchema for UsersGeneratingSettings

Source

impl JsonSchema for Gift

Source

impl JsonSchema for GiftTemplate

Source

impl JsonSchema for InitParams

Source

impl JsonSchema for AutoChestSettings

Source

impl JsonSchema for InventoryLevel

Source

impl JsonSchema for ItemCaseRarityWeight

Source

impl JsonSchema for ItemCasesSettingsByLevel

Source

impl JsonSchema for Attribute

Source

impl JsonSchema for Item

Source

impl JsonSchema for ItemAttribute

Source

impl JsonSchema for ItemAttributeSettings

Source

impl JsonSchema for ItemRarity

Source

impl JsonSchema for ItemTemplate

Source

impl JsonSchema for ArenaPlaceRestriction

Source

impl JsonSchema for ArenaRatingRestriction

Source

impl JsonSchema for Mail

Source

impl JsonSchema for MailRestrictions

Source

impl JsonSchema for MailSendType

Source

impl JsonSchema for MailTemplate

Source

impl JsonSchema for PVEProgressRestriction

Source

impl JsonSchema for PowerRestriction

Source

impl JsonSchema for MatchmakingCache

Source

impl JsonSchema for Offer

Source

impl JsonSchema for OfferTemplate

Source

impl JsonSchema for OffersInfo

Source

impl JsonSchema for ShopTabConfig

Source

impl JsonSchema for OpponentPreview

Source

impl JsonSchema for OpponentStateBot

Source

impl JsonSchema for OpponentStateHuman

Source

impl JsonSchema for RatingCalculationData

Source

impl JsonSchema for PartyMemberPreview

Source

impl JsonSchema for EquippedPets

Source

impl JsonSchema for Pet

Source

impl JsonSchema for PetComputedSecondaryStat

Source

impl JsonSchema for PetDrop

Source

impl JsonSchema for PetRarity

Source

impl JsonSchema for PetSecondaryStat

Source

impl JsonSchema for PetTemplate

Source

impl JsonSchema for UpgradedPetsMap

Source

impl JsonSchema for MatchmakingData

Source

impl JsonSchema for MatchmakingOpponent

Source

impl JsonSchema for Opponent

Source

impl JsonSchema for PVPState

Source

impl JsonSchema for RatingChange

Source

impl JsonSchema for VassalPvpOpponent

Source

impl JsonSchema for VassalPvpPlayersFindRequest

Source

impl JsonSchema for QuestInstance

Source

impl JsonSchema for QuestTemplate

Source

impl JsonSchema for QuestsGroups

Source

impl JsonSchema for QuestsProgressTrack

Source

impl JsonSchema for QuestsProgressionGroup

Source

impl JsonSchema for QuestsProgressionPointSettings

Source

impl JsonSchema for QuestsProgressionSettings

Source

impl JsonSchema for QuestsTrackReward

Source

impl JsonSchema for RatingLeaderboardRequest

Source

impl JsonSchema for RatingRangeReward

Source

impl JsonSchema for RatingRankingItem

Source

impl JsonSchema for RatingSettings

Source

impl JsonSchema for GetReferralsRequest

Source

impl JsonSchema for Patron

Source

impl JsonSchema for ReferralLevelInfo

Source

impl JsonSchema for ReferralWithExp

Source

impl JsonSchema for ShareLinkParam

Source

impl JsonSchema for CharacterSkins

Source

impl JsonSchema for ConfigSkin

Source

impl JsonSchema for SkinsSettings

Source

impl JsonSchema for StatueBonusGrade

Source

impl JsonSchema for StatueBonusSlot

Source

impl JsonSchema for StatueSet

Source

impl JsonSchema for StatueSlotsMap

Source

impl JsonSchema for StatueState

Source

impl JsonSchema for TalentAttributeBonus

Source

impl JsonSchema for TalentLevel

Source

impl JsonSchema for TalentLevelsMap

Source

impl JsonSchema for TalentPosition

Source

impl JsonSchema for TalentTemplate

Source

impl JsonSchema for TalentTreeSettings

Source

impl JsonSchema for TalentUnlockCondition

Source

impl JsonSchema for CustomValuesMap

Source

impl JsonSchema for User

Source

impl JsonSchema for Suzerain

Source

impl JsonSchema for Vassal

Source

impl JsonSchema for VassalTask

Source

impl JsonSchema for VassalTaskTemplate



impl JsonSchema for Uuid